@@ -43,6 +43,7 @@
 #include "commands/matrixcommands.h"
 #include "commands/blockmatrixcommands.h"
 #include "commands/matrixqueries.h"
+#include "commands/combinatronics.h"
 
 #include <config-analitza.h>
 #ifdef HAVE_EIGEN3
@@ -176,6 +177,8 @@ void Analyzer::registerBuiltinMethods()
     m_builtin.insertFunction(IsZeroMatrixCommand::id, IsZeroMatrixCommand::type, new IsZeroMatrixCommand);
     m_builtin.insertFunction(IsIdentityMatrixCommand::id, IsIdentityMatrixCommand::type, new IsIdentityMatrixCommand);
     m_builtin.insertFunction(IsDiagonalMatrixCommand::id, IsDiagonalMatrixCommand::type, new IsDiagonalMatrixCommand);
+    m_builtin.insertFunction(CombinationCommand::id, CombinationCommand::type, new CombinationCommand);
+    m_builtin.insertFunction(PermutationCommand::id, PermutationCommand::type, new PermutationCommand);
 #ifdef HAVE_EIGEN3
     m_builtin.insertFunction(EigenvaluesCommand::id, EigenvaluesCommand::type, new EigenvaluesCommand);
     m_builtin.insertFunction(EigenvectorsCommand::id, EigenvectorsCommand::type, new EigenvectorsCommand);
@@ -354,7 +357,8 @@ Object* Analyzer::eval(const Object* branch, bool resolve, const QSet<QString>&
             }    break;
             case Container::lambda: {
                 QSet<QString> newUnscoped(unscoped);
-                newUnscoped+=c->bvarStrings().toSet();
+                const auto &bvarString = c->bvarStrings();
+                newUnscoped+ QSet<QString>(bvarString.begin(), bvarString.end());
                 
                 Container *r = c->copy();
                 Object* old=r->m_params.last();
@@ -475,7 +479,8 @@ Object* Analyzer::eval(const Object* branch, bool resolve, const QSet<QString>&
                 int top = m_runStack.size();
                 bool resolved=false;
                 
-                QSet<QString> bvars = c->bvarStrings().toSet();
+                const auto &bvarString = c->bvarStrings();
+                QSet<QString> bvars = QSet<QString>(bvarString.begin(), bvarString.end());
                 newUnscoped += bvars;
                 m_runStack.resize(top + bvars.size());
                 
@@ -1351,7 +1356,9 @@ Object* Analyzer::simpApply(Apply* c)
             
             //if bvars is empty, we are dealing with an invalid sum()
             Object* function = *c->firstValue();
-            if(!bvars.isEmpty() && !domain && !hasTheVar(bvars.toSet(), function)) {
+
+            const auto barsSet = QSet<QString>(bvars.begin(), bvars.end());
+            if(!bvars.isEmpty() && !domain && !hasTheVar(barsSet, function)) {
                 Apply *cDiff=new Apply;
                 cDiff->appendBranch(new Operator(Operator::minus));
                 cDiff->appendBranch(uplimit  ->copy());
@@ -1706,7 +1713,8 @@ Object* Analyzer::simpSum(Apply* c)
     Apply* cval=static_cast<Apply*>(*c->firstValue());
     
     if(cval->isApply() && cval->firstOperator()==Operator::times) {
-        QSet<QString> bvars=c->bvarStrings().toSet();
+        const auto &bvarString = c->bvarStrings();
+        QSet<QString> bvars = QSet<QString>(bvarString.begin(), bvarString.end());
         QVector<Object*> sum, out;
         Apply::iterator it=cval->firstValue(), itEnd=cval->end();
         int removed=0;
